@@ -6,5 +6,4 @@ from controller import Controller
 from measure import Measure
 from range import Range
 from state import State
-
-import cookie
+from cookie import Cookie, store
